ChatTheme class

Constructors

ChatTheme({Color primaryColor = Colors.blue, Color secondaryColor = Colors.grey, Color backgroundColor = Colors.white, Color userBubbleColor = Colors.blue, Color assistantBubbleColor = Colors.grey, Color errorBubbleColor = Colors.red, Color textColor = Colors.white, Color inputBackgroundColor = Colors.white, double borderRadius = 12.0, EdgeInsetsGeometry bubblePadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8), EdgeInsetsGeometry messageListPadding = const EdgeInsets.all(16), TextStyle? userTextStyle, TextStyle? assistantTextStyle, TextStyle? errorTextStyle, TextStyle? inputTextStyle, int inputMaxLines = 5, Widget? sendButtonIcon, bool showAvatars = true, bool showTimestamps = true})
const

Properties

assistantBubbleColor Color
final
assistantTextStyle TextStyle?
final
backgroundColor Color
final
borderRadius double
final
bubblePadding EdgeInsetsGeometry
final
errorBubbleColor Color
final
errorTextStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
inputBackgroundColor Color
final
inputMaxLines int
final
inputTextStyle TextStyle?
final
messageListPadding EdgeInsetsGeometry
final
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
final
sendButtonIcon Widget?
final
showAvatars bool
final
showTimestamps bool
final
textColor Color
final
userBubbleColor Color
final
userTextStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dark() ChatTheme
light() ChatTheme