ChatUser class

Constructors

ChatUser({required String id, required String name, String? avatarUrl, Widget? avatarWidget, Color? color})
const

Properties

avatarUrl String?
final
avatarWidget Widget?
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

assistant → const ChatUser
user → const ChatUser