AIService class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearContext(
) → Future< void> - Clear conversation context
-
isAvailable(
) → Future< bool> - Check if service is available
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
{required String message, List< ChatMessage> conversationHistory, Map<String, dynamic> ? options}) → Future<String> - Send a message and get a complete response
-
sendMessageStream(
{required String message, List< ChatMessage> conversationHistory, Map<String, dynamic> ? options}) → Stream<String> - Send a message and get a streaming response
-
setOptions(
Map< String, dynamic> options) → void - Set custom options
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited